#
# spec file for package libyui
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libyui
Version:        3.2.6
Release:        1.2
Source:         %{name}-%{version}.tar.bz2

%define so_version 7
%define bin_name %{name}%{so_version}

BuildRequires:  boost-devel
BuildRequires:  cmake >= 2.8
BuildRequires:  gcc-c++
BuildRequires:  pkg-config

Url:            http://github.com/libyui/
Summary:        GUI-abstraction library
License:        LGPL-2.1 or LGPL-3.0
Group:          System/Libraries

%description
This is the user interface engine that provides the abstraction from
graphical user interfaces (Qt, Gtk) and text based user interfaces
(ncurses).

Originally developed for YaST, it can now be used independently of
YaST for generic (C++) applications. This package has very few
dependencies.

%package -n %{bin_name}

Provides:       yast2-libyui = 2.42.0
Obsoletes:      yast2-libyui < 2.42.0
Requires:       yui_backend = %{so_version}

Url:            http://github.com/libyui/
Summary:        Libyui - GUI-abstraction library
Group:          System/Libraries

%description -n %{bin_name}
This is the user interface engine that provides the abstraction from
graphical user interfaces (Qt, Gtk) and text based user interfaces
(ncurses).

Originally developed for YaST, it can now be used independently of
YaST for generic (C++) applications. This package has very few
dependencies.


%package devel

Requires:       %{bin_name} = %{version}
Requires:       boost-devel
Requires:       glibc-devel
Requires:       libstdc++-devel

Url:            http://github.com/libyui/
Summary:        Libyui header files
Group:          Development/Languages/C and C++

%description devel
This is the user interface engine that provides the abstraction from
graphical user interfaces (Qt, Gtk) and text based user interfaces
(ncurses).

Originally developed for YaST, it can now be used independently of
YaST for generic (C++) applications. This package has very few
dependencies.

This can be used independently of YaST for generic (C++) applications.
This package has very few dependencies.


%prep
%setup -q -n %{name}-%{version}

%build

./bootstrap.sh

export CFLAGS="$RPM_OPT_FLAGS -DNDEBUG $(getconf LFS_CFLAGS)"
export CXXFLAGS="$RPM_OPT_FLAGS -DNDEBUG $(getconf LFS_CFLAGS)"

mkdir build
cd build

%if %{?_with_debug:1}%{!?_with_debug:0}
cmake .. \
        -DYPREFIX=%{_prefix} \
        -DDOC_DIR=%{_docdir} \
        -DLIB_DIR=%{_lib} \
        -DCMAKE_BUILD_TYPE=RELWITHDEBINFO
%else
cmake .. \
        -DYPREFIX=%{_prefix} \
        -DDOC_DIR=%{_docdir} \
        -DLIB_DIR=%{_lib} \
        -DCMAKE_BUILD_TYPE=RELEASE
%endif

make %{?jobs:-j%jobs}

%install
cd build
make install DESTDIR="$RPM_BUILD_ROOT"
install -m0755 -d $RPM_BUILD_ROOT/%{_docdir}/%{bin_name}/
install -m0755 -d $RPM_BUILD_ROOT/%{_libdir}/yui
install -m0644 ../COPYING* $RPM_BUILD_ROOT/%{_docdir}/%{bin_name}/

%clean
rm -rf "$RPM_BUILD_ROOT"

%post -n %{bin_name} -p /sbin/ldconfig

%postun -n %{bin_name} -p /sbin/ldconfig

%files -n %{bin_name}
%defattr(-,root,root)
%dir %{_libdir}/yui
%dir %{_datadir}/libyui
%{_libdir}/lib*.so.*
%doc %dir %{_docdir}/%{bin_name}
%doc %{_docdir}/%{bin_name}/COPYING*

%files devel
%defattr(-,root,root)
%dir %{_docdir}/%{bin_name}
%{_libdir}/lib*.so
%{_prefix}/include/yui
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}
%{_datadir}/libyui/buildtools
%doc %{_docdir}/%{bin_name}/examples

%changelog
* Mon Aug 22 2016 jreidinger@suse.com
- prevent double rendering of content causing segfault in qt and
  slow down elsewhere (bnc#989155)
- 3.2.6
* Wed Mar 30 2016 me@besser82.io
- Fix 'Werror=nonnull-compare' for GCC 6 (bsc#964144)
  - Optimizations remove null pointer checks for 'this'
- Clean-up trailing white-space
- 3.2.5
* Fri Jan 29 2016 mvidner@suse.com
- Fixed a compilation error in YTableCell with GCC 6 (bsc#964144).
- 3.2.4
* Wed Sep 16 2015 mvidner@suse.com
- Reorganized git for easier tarball creation:
  - RPM spec files are kept in git verbatim, not as templates
  - no longer call PREP_SPEC_FILES in CMakeLists.common
- No functional change but version bumped to push the package
  down the pipeline (boo#946079).
* Fri Aug 28 2015 mvidner@suse.com
- Bump also the required yui_backend
- 3.2.2
* Wed Jul 29 2015 besser82@fedoraproject.org
- API-changes imply so-name bump
- 3.2.1
* Wed Jul  8 2015 mvidner@suse.com
- Added YApplication::openUI/closeUI (boo#937026)
- 3.2.0
* Tue Jan 20 2015 mvidner@suse.com
- Fix cmake also in the spec file, duh.
* Mon Jan 12 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (-fPIC, PREFIX, boo#911875).
- 3.1.5
* Wed Aug 27 2014 locilka@suse.com
- The default product name should be "SUSE Linux" (bnc#886608)
- 3.1.4
* Mon Aug 25 2014 lslezak@suse.cz
- Detect lib64 in a Debian compatible way, for Travis CI.
* Sat May 24 2014 bjoern.esser@gmail.com
- pull in GPLv3-license, since LGPLv3 is additional rules on top
- 3.1.3
* Thu Apr 17 2014 jsrain@suse.cz
- Added handling of logo bar in wizard (bnc#868722)
- 3.1.2
* Wed Apr 16 2014 mvidner@suse.com
- Fix YQUI destruction (bnc#867296).
- 3.1.1
* Wed Apr  9 2014 mvidner@suse.com
- Added YUIOpt_titleOnLeft, YWizardMode_TitleOnLeft (bnc#868859)
- 3.1.0
* Fri Feb 21 2014 mvidner@suse.com
- now building on https://ci.opensuse.org/view/libyui/ !
  - adapted CMake macros for PREFIX != /usr
  - use Rakefile for making srcpackage for OBS
* Fri Feb  7 2014 jsrain@suse.cz
- use text version of release notes with NCurses (bnc#862578)
- 3.0.13
* Wed Dec 11 2013 anaselli@linux.it
- added external widget plugin management
- added support for multi plugin loader (one per name)
- Version 3.0.12
* Thu Dec  5 2013 mvidner@suse.com
- Added a new option for YPushButton: YUIOpt_relNotesButton;
  it will pop up a dialog with externally provided release notes.
  (by jsrain)
- Added a generic plugin loader libyui-NAME-[qt|gtk|ncurses]
  to manage user defined external widget (by anaselli)
- 3.0.11
* Tue Aug  6 2013 tgoettlicher@suse.de
- Fixed dependencies
- Version 3.0.10
* Wed Jul 24 2013 tgoettlicher@suse.de
- fixed bnc#752278: ComboBox does not show active item when item
  with empty label is present
- Version 3.0.9
* Sun Jun 30 2013 anaselli@linux.it
- git describe and git --tags do not always return a git hash
  to avoid cmake failure a check has been introduced with a warning
  message
- skipping also .kdev4 when building source package
* Wed Jun 26 2013 tgoettlicher@suse.de
- Fixed build of libyui-qt-graph examples
- Version 3.0.8
* Mon Jun 24 2013 anaselli@linux.it
- fixed the use of -DGIT_VERSION=on
- Version 3.0.7
* Sat Jun  1 2013 bjoern.esser@gmail.com
- fix build with graphviz >= 2.30.0
- Version 3.0.6
* Wed May 15 2013 bjoern.esser@gmail.com
- respect compiler flags of system rpm config when building RELEASE
  by adding -DRESPECT_FLAGS to cmake
- add -DSKIP_LATEX to skip generation of LaTeX-based PDF-generation
  when invoking `make docs`
- Version 3.0.5
* Fri May 10 2013 bjoern.esser@gmail.com
- checking prefix in -doc pkg is obsolete
- use bootstrap.sh for legacy in -doc pkg here, too
* Fri May 10 2013 bjoern.esser@gmail.com
- use a common toplevel CMakeLists.txt
- fix building *-doc pkgs
- Version 3.0.4
* Mon May  6 2013 bjoern.esser@gmail.com
- fix build issues with ncurses and qt
- Version 3.0.3
* Mon May  6 2013 bjoern.esser@gmail.com
- use SONAME from libyui instead of VERSION.cmake if plugin
- bumped up patch-version to 3.0.2
- disabled auto-gen of docs
  INSTALL_DOCS=ON will no longer auto-gen the docs
  added a warning to run "make docs" before "make install"
- add DOC_SUBDIR to CMake-Vars
  some distributions prefer %%{name}-%%{version} over
  %%{name}-%%{soname_major} as doc-subdir.
* Tue Apr 30 2013 tgoettlicher@suse.de
- Increased version because of changed function names
- Version 3.0.1
* Fri Feb  8 2013 tgoettlicher@suse.de
- Code clean-up: removed java-like get-prefix
- Version 2.42.7
* Mon Feb  4 2013 tgoettlicher@suse.de
- Added setLocaleDir(), getLocaleDir()
- Version 2.42.6
* Sat Jan 19 2013 anaselli@linux.it
- wrong path for Libyui_config.h
* Fri Jan 18 2013 anaselli@linux.it
- Fixed YSettings
- Added setThemeDir(), getThemeDir(), setIconsDir() and
  getIconsDir() to YSettings
* Mon Jan  7 2013 tgoettlicher@suse.de
- Removed needless loadPluginLib() from header file
- Version 2.42.4
* Fri Nov  2 2012 anaselli@linux.it
- Added new API to managed application title and icon
- Added the availiability to build a git sha1 versioned package using cmake -DGIT_VERSION=on
* Fri Sep  7 2012 tgoettlicher@suse.de
- Version 2.42.2
* Tue Sep  4 2012 tgoettlicher@suse.de
- Fixed requirements in doc spec file
* Wed May  2 2012 tgoettlicher@suse.de
- Fixed bnc#753784: YaST help dialogs appear fullscreen
- Version: 2.21.4
* Thu Apr 12 2012 tgoettlicher@suse.de
- Fix build with gcc 4.7.
* Fri Mar 16 2012 tgoettlicher@suse.de
- Fixed bnc#722325: untranslated rpm groups
- Version: 2.21.3
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Nov 16 2011 tgoettlicher@suse.de
- Fixed bnc#713343: YaST ncurses help screen is too small
- Version: 2.21.2
* Tue Apr 19 2011 tgoettlicher@suse.de
- Don't allow recursive selection for non-multiselection widgets
- V 2.21.1
* Fri Apr 15 2011 tgoettlicher@suse.de
- Added support for recursive selection in tree widgets
- V 2.20.3
* Fri Feb 11 2011 tgoettlicher@suse.de
- Fixed segfault for currentItem on tree widget
- V 2.20.2
* Tue Feb  8 2011 tgoettlicher@suse.de
- Added support for currentItem to tree widget
- V 2.20.1
* Thu Feb  3 2011 tgoettlicher@suse.de
- V 2.20.0
* Mon Dec 20 2010 tgoettlicher@suse.de
- Added support for check boxes in tree widgets
- V 2.19.2
* Fri Apr  9 2010 tgoettlicher@suse.de
- Fixed endless loop in layout algorithm  (bnc #558699)
- V 2.19.1
* Tue Mar  2 2010 coolo@novell.com
- Fixing undefined behaviour that triggers a crash with
  gcc 4.5 (bnc#582088)
- V 2.19.0
* Tue Feb  9 2010 tgoettlicher@suse.de
- added license headers
* Tue Jul 28 2009 kmachalkova@suse.cz
- Search for icons in several possible directories (using
  /usr/share/icons/hicolor as fallback) - holds for everything
  derived from SelectionWidget (FaTE #306356)
- V 2.18.8
* Fri Mar  6 2009 tgoettlicher@suse.de
- Added context menus
- V 2.18.7
* Sun Mar  1 2009 coolo@suse.de
- hopefully last fix ;(
* Sun Feb 22 2009 coolo@suse.de
- another fix
- V 2.18.6
* Wed Feb 18 2009 coolo@suse.de
- fix compilation with gcc 4.4
- V 2.18.5
* Mon Feb  9 2009 sh@suse.de
- Added virtual destructor for YTableCell for better
  NCFileSelection support
- V 2.18.4
* Tue Jan 27 2009 aschnell@suse.de
- extended YGraph for simple user-interaction
- V 2.18.3
* Fri Jan 16 2009 kkaempf@suse.de
- Fix bnc#427372 once more, YWidgetFactory:createTable was missing
* Thu Jan 15 2009 sh@suse.de
- Fixed bnc #427372: Specify class ownership for SWIG bindings
* Wed Jan 14 2009 aschnell@suse.de
- added graph widget
- V 2.18.2
* Wed Jan  7 2009 sh@suse.de
- Fixed bnc #461617: Glyph ArrowLeft / ArrowRight in Arabic
* Wed Oct 15 2008 sh@suse.de
- Added `opt(`confirmUnsupported) for PackageSelector widget
  (bnc #435479)
- V 2.17.14
* Thu Oct  9 2008 sh@suse.de
- Prevent segfault when deleting YEventFilters in YDialog dtor
- Prevent segfault in YEventFilter with default args
- V 2.17.13
* Fri Sep 26 2008 tgoettlicher@suse.de
- Fixed bnc #418443: Yast modules windows have no title
- V 2.17.12
* Wed Sep 24 2008 sh@suse.de
- Improved robustness against already-deleted widgets (bnc #421794)
- V 2.17.11
* Wed Sep 17 2008 sh@suse.de
- Fixed reverse layout (for Arabic, Hebrew) in YButtonBox
* Fri Sep 12 2008 sh@suse.de
- Improved resize behaviour of YDialogSpy
* Fri Sep 12 2008 sh@suse.de
- Added widget properties to YDialogSpy
- V 2.17.10
* Fri Sep 12 2008 sh@suse.de
- Now exporting more YWidget base class attributes as properties:
  HWeight, VWeight, HStretch, VStretch
* Thu Sep 11 2008 sh@suse.de
- Added highlighting for target dialog in YDialogSpy
- V 2.17.9
* Wed Sep 10 2008 sh@suse.de
- Force [Help] button left-aligned in GNOME button order
* Tue Sep  9 2008 sh@suse.de
- Added YDialogSpy for interactive introspection of a widget tree
- V 2.17.8
* Tue Sep  9 2008 sh@suse.de
- Made YEvents more robust against attempts of duplicate deletion
- Stream output (logging) for YEvents
* Thu Sep  4 2008 sh@suse.de
- Allow ButtonBox sanity check to be relaxed (bnc #422612)
- V 2.17.7
* Thu Aug 21 2008 sh@suse.de
- Added YButtonBox widget (fate #303446)
- V 2.17.6
* Tue Jul 15 2008 sh@suse.de
- Implemented fate #303492: Multi selection for table widget
- V 2.17.5
* Fri Jul 11 2008 sh@suse.de
- Fixed bnc #367023: Keyboard shortcuts for non-ASCII languages
- V 2.17.4
* Tue Jul  8 2008 sh@suse.de
- Enable keyboard shortcuts for YDumbTab widgets (fate #304890)
- V 2.17.3
* Wed Jun 18 2008 sh@suse.de
- Introduced YEventFilter to improve support for higher-level
  widgets that might send and need to handle internal events
- V 2.17.2
* Wed Jun 11 2008 sh@suse.de
- Introduced YUITerminator to make sure the UI is properly shut
  down in all cases, regardless if called from YCP or plain C++
- V 2.17.1
* Wed May 28 2008 sh@suse.de
- Added YWizard::wizardMode() for bnc #393040
- V 2.16.48
* Wed Apr 30 2008 lslezak@suse.cz
- added repoMgrEnabled() method to YPackageSelector widget
  (repository management is now optional) (bnc#381956)
- V 2.16.47
* Wed Apr 23 2008 sh@suse.de
- Fixed segfault when discarding events from foreign dialogs
  (bnc #382771)
- V 2.16.46
* Wed Apr 16 2008 sh@suse.de
- Deleting events is now automatically handled by YDialog.
  Simply remove all "delete event" calls.
- Introduced uiThreadDestructor() (bnc #346987)
- V 2.16.45
* Mon Apr 14 2008 sh@suse.de
- Added dialog type YWizardDialog for main dialogs that will
  contain a wizard (equivalent to YMainDialog if
  YApplication::hasWizardDialogSupport() returns false)
- V 2.16.44
* Fri Apr 11 2008 sh@suse.de
- Reverted last changes - sub-wizards seem to be a dead end
- V 2.16.43
* Thu Apr 10 2008 sh@suse.de
- Added support for docked sub-wizards
- V 2.16.42
* Thu Apr  3 2008 sh@suse.de
- Added YPushButton::setHelpButton() and isHelpButton()
- Automatically show topmost YWidget::helpText() when a help button
  is activated
- V 2.16.41
* Tue Apr  1 2008 sh@suse.de
- Added "HelpText" property to YWidget for easier support of
  YCP wizard layouts without permanent help panel (fate #303291)
* Thu Mar 20 2008 sh@suse.de
- Added standard file logger (when used independently of YaST2)
- V 2.16.40
* Wed Mar  5 2008 sh@suse.de
- Fixed bnc #365999: Shift-F7 affects only UI logging
- V 2.16.39
* Tue Mar  4 2008 sh@suse.de
- Conflict with yast2-core < 2.16.38 (before pkg split)
* Tue Feb 26 2008 sh@suse.de
- Added cmake support for dependent packages
- V 2.16.38
* Thu Feb 21 2008 sh@suse.de
- Package split off from yast2-core
- V 2.16.37
* Tue Feb  5 2008 sh@suse.de
  * Macro recording and playing ins now unified and moved out of the YUI class.
  Use the static functions in the new YMacro class instead now:
  - YMacro::record()
  - YMacro::play()
  ...
  * Moved productName() and setProductName() from YUI to YApplication
* Thu Jan 31 2008 sh@suse.de
  * Moved event handling from YUI to YDialog:
  - removed YUI::userInput()
  - removed YUI::pollInput()
  - Derived classes now have to implement:
  - YDialog::waitForEventInternal()
  - YDialog::pollEventInternal()
* Wed Jan 30 2008 sh@suse.de
  * Moved dialog handling from YUI to YDialog:
  - removed YUI::showDialog()
  - removed YUI::closeDialog()
  - Now using YDialog::open() and YDialog::destroy()
  - Derived classes now have to implement:
  - YDialog::openInternal()
  - YDialog::activate()
* Mon Jan 28 2008 sh@suse.de
  * Moved YCP part out of YEvent to new class YCPEvent
  * YUI::runPkgSelection() now returns YEvent * and is pure virtual
* Thu Jan 24 2008 sh@suse.de
  * UI::OpenDialog() now opens error dialog in case of exception
  (using the new mod-ui calls, works for all UIs)
  * UI::UserInput() now opens error dialog in case of exception
  (using the new mod-ui calls, works for all UIs)
* Sat Jan 19 2008 sh@suse.de
  * Moved glyph handling from YUI to YApplication,
  now using std::string instead of YCPString and YCPSymbol;
  forget YMyUI::glyph(), implement YMyApplication::glyph()
* Sun Dec  9 2007 sh@suse.d
  * Moved file and directory dialogs from YUI to YApplication:
  - askForExistingDirectory()
  - askForExistingFile()
  - askForSaveFile()
  * Parameters and return values now all std::string
  * Now return empty string upon user cancel
* Thu Nov 29 2007 sh@suse.de
  * Migrated YDialog
  * Removed YContainerWidget for good
  * Removed legacy YWidget::queryWidget() and YWidget::changeWidget() methods
  * Dropped support for outdated property handling with old
  YWidget::queryWidget() and YWidget::changeWidget() methods
  * Dropped support for outdated YWidget( YWidgetOpt ) constructors
  * Removed unneeded YWidgetOpt fields
  * Added basic default button handling to YDialog and YPushButton
* Mon Nov 26 2007 sh@suse.de
  * Migrated YWizard
  * Moved WizardCommand parsing out to YCPWizardCommandParser
  * Added lots of pure virtual functions to YWizard
  * All YCPValue and other YCP related code can now be removed from
    YWizard-derived classes
* Tue Nov 13 2007 sh@suse.de
  * Migrated YDumbTab
  * YDumbTab now inherits YSelectionWidget
* Sun Nov 11 2007 sh@suse.de
  * Enforced creating YWidget and derived classes with new (on the heap)
  * Ported YDownloadProgress
* Thu Nov  8 2007 sh@suse.de
  * Ported YBarGraph
  * Ported YPartitionSplitter
* Mon Nov  5 2007 sh@suse.de
  * Ported default function key handling
* Tue Oct 30 2007 sh@suse.de
  * Renamed YTime -> YTimeField
  * Renamed YDate -> YDateField
  * Ported YTimeField
  * Ported YDateField
* Mon Oct 29 2007 sh@suse.de
  * Moved opaque 'data' void pointer from YTreeItem / YTableItem
  to YItem base class
* Thu Oct 25 2007 sh@suse.de
  * Changed YTable header handling (bubli's request):
  - Constructor now gets YTableHeader object
  - no more setHeader() and setAlignment functions - get rid of them
  - use columns(), header(), alignment() in the constructor to set up columns
* Wed Oct 10 2007 sh@suse.de
  * Ported MenuButton
  - Now derived from YSelectionWidget
  - Added support for replacing (all!) items
  - QueryWidget can now return the complete item term
  - Added support for icons in menu entries
  - Added YMenuEvent( YMenuEntry * ) constructor
  - Derived classes can use YMenuItem::index() as a unique ID
    or use YMenuItem::data() and YMenuItem::setData() to store
    a custom pointer to some other class.
  Look at YQMenuButton for a sample implementation.
* Tue Oct  9 2007 sh@suse.de
  * Ported LogView
* Mon Oct  8 2007 sh@suse.de
  * Added support for QueryWidget(`id(...), `Items ) for SelectionWidgets:
  - SelectionBox
  - ComboBox
  - MultiSelectionBox
  - Tree
  - Table
  * Ported IntField
* Fri Oct  5 2007 sh@suse.de
  * Ported Table
  - now based on SelectionWidget
  - much streamlined with the other selection widgets
  - QueryWidget can now return the complete item term
    as well as individual cells
  Look at YQTable for a sample implementation.
* Fri Jul 13 2007 sh@suse.de
  * Ported MultiProgressMeter
  - now using float values internally to safeguard against huge numbers
* Fri Jul  6 2007 sh@suse.de
  * Ported YTree
* Tue Jul  3 2007 sh@suse.de
  * Ported YMultiLineEdit
  - renamed text()    -> value()
  - renamed setText() -> setValue()
  - new: YMultiLineEdit::defaultVisibleLines() (use this in preferredHeight() )
  * Ported YProgressBar
  - renamed setProgress() -> setValue()
* Mon Jul  2 2007 sh@suse.de
  * Ported simple YSelectionWidgets (major rewrite):
  - YSelectionBox
  - YComboBox
  - YMultiSelectionBox
  Most (almost all?) of the selection handling went to the YSelectionWidget
  base class. The concrete UI implementations have to implement 2 pure virtual
  functions each - see the respective header files. See the YQ sample
  implementations for more details.
  * YComboBox now also supports icons.
* Fri Jun 29 2007 sh@suse.de
  * Added YSelectionBox::immediateMode() and setImmediateMode()
  as a replacement for YWidgetOpt.immediateMode
  * Added YSelectionBox::shrinkable() and setShrinkable()
  as a replacement for YWidgetOpt.shrinkable
* Wed Jun 27 2007 sh@suse.de
  * YPackageSelector:
  * added modeFlags parameter (summarizing all the YWidgetOpts)
  * added mode checking functions:
  - bool testMode()
  - bool onlineUpdateMode()
  - bool updateMode()
  - ...
  * Dropped long-obsolete floppyDevice parameter
  * YPackageSelectorPlugin:
  * added modeFlags parameter
  * Factories:
  * added modeFlags parameter for PackageSelector etc.
  * now calling the YPackagePlugin from the factory create...() functions
* Wed Jun 27 2007 sh@suse.de
  * YImage:
  * Dropped support for creating an image from a YCPByteblock
  * Dropped support for fallback label (was never used in NCurses anyway)
  * Dropped support for `opt(`tiled)
  * Moved YWidgetOpt stuff to YImage methods
* Tue Jun 26 2007 sh@suse.de
  * Renamed YWidget::getNotify() -> YWidget::notify()
  Replace with:
  perl -p -i -e 's/getNotify/notify/g' *.cc pkg/*.c
  * Added function key methods for NCurses F-key support:
  - YWidget::functionKey()
  - YWidget::hasFunctionKey()
  - virtual YWidget::setFunctionKey
  Since YWidgetOpt is no longer passed to constructors, NCurses should use
  those new functions instead.
  YWidget::setFunctionKey() is called from YCPDialogParser after the widget is
  created, so either use the new function in the keyboard handlers or overwrite
  YWidget::setFunctionKey().
  * YCheckBox:
  - getValue() -> value()
  - no longer just boolean values, now using YCheckBoxState enum: _on, _off, _dont_care
  - YCheckBox constructor doesn't accept an initiallyChecked value any more
    (but derived classes should so the widgetFactory can pass it on easily)
* Mon Jun 25 2007 sh@suse.de
  * Renamed YTextEntry -> YInputField
  For YCP, TextEntry is (and will remain) still a valid widget name.
  `InputField is the new default name, though.
* Mon Jun 25 2007 sh@suse.de
  * changed nicesize() to preferredWidth() and preferredHeight(), both returning int, not long
  see longer explanations on top
  * virtual YWidget::setSize() now has int params, no longer long
  see longer explanations on top
* Fri Jun 22 2007 sh@suse.de
  * added pure virtual YWidgetFactory::createSpacing()
  Removed from derived factories:
  - YWidgetFactory::createHStretch() is no longer virtual and now returns a YSpacing
  - YWidgetFactory::createVStretch() is no longer virtual and now returns a YSpacing
  - YWidgetFactory::createHSpacing() is no longer virtual and now returns a YSpacing
  - YWidgetFactory::createVSpacing() is no longer virtual and now returns a YSpacing
  * Droppped HVStretch widget
* Thu Jun 21 2007 sh@suse.de
  * Dropped YColoredLabel
  * Moved widget term parsing stuff to separate class YCPDialogParser
  * YUI::widgetWithId() is now YCPDialogParser::findWidgetWithId()
  !!! the default for throwing exceptions is now reverted: It now throws by default!
  - >  YUI::widgetWithId( someId, true )  -> YCPDialogParser::findWidgetWithId( someId )
  - >  YUI::widgetWithId( someId )        -> YCPDialogParser::findWidgetWithId( someId, false )
  - >  YUI::widgetWithId( someId, false ) -> YCPDialogParser::findWidgetWithId( someId, false )
* Thu Jun 21 2007 sh@suse.de
  * YRichText:
  virtual setText() -> virtual setValue()
  virtual getText() -> virtual value()
  setText() is still there, but no longer virtual - implement setValue() instead!
  new (instead of YWidgetOpt() ):
  - bool plainTextMode() const;
  - virtual void setPlainTextMode( bool on = true );
  - bool autoScrollDown() const;
  - virtual void setAutoScrollDown( bool on = true );
  - bool shrinkable() const;
  - void setShrinkable( bool shrinkable = true );
* Thu Jan  2 1997 sh@suse.de
  * Parameter YRadioButtonGroup now obsolete:
  YRadioButtons traverse the YWidget hierarchy upwards to find
  their parent YRadioButtonGroup. There is no more need to pass
  the YRadioButtonGroup as a parameter through all kinds of
  calls.
  This had cluttered the API for a long time.
  * Got rid of all YCP data types in all widget classes:
  * YCPString		-> std::string
  * YCPInteger	-> int
  * YCPBoolean	-> bool
  * In function parameters, std::string is generally passed as const std::string & .
  * All widgets: No longer implementing changeWidget() / queryWidget() directly,
  now using setProperty() / getProperty().
  Reason: No more YCP depencency in YWidget derived classes.
  See YRadioButton or YTextEntry for examples.
  * All widgets: widgetClass() now returns const char *, no longer char *
  (gcc had already complained in abuild about this)
  auto-replace this with:
  perl -p -i -e 's/virtual char \*widgetClass/virtual const char *widgetClass/' *.h
  * All widgets: nicesize() was replaced by preferredWidth() and preferredHeight().
  Both return an int, not a long like nicesize() did: int is plenty for pixel
  coordinates, and it's a LOT less hassle.
  The rationale for splitting up nicesize() (and giving it an English name, no
  longer German_en) was that in 95%% of all cases the first thing an
  implementation does is something like
    if ( dim == YD_HORIZ )
    // calculate width
    else
    // calculate height
  If you must (though this is discouraged), you can still reimplement
    int YWidget::preferredSize( YUIDimension dim )
  which now by default calls preferredWidth() and preferredHeight().
  Use the perl scripts from ~sh/Export/ for easier transition:
  (but by all means do "svn ci" immediately before so you can easily revert):
    mod-ui-change-nicesize-header *.h
    mod-ui-change-nicesize-src *.cc
  This doesn't do the work completely, but it's a good starting point.
  * All widgets: The parameters of YWidget::setSize() are now int, no longer long.
  The reasoning is the same as with long nicesize() vs. int preferredWidth().
  Use the perl scripts from ~sh/Export/ for easier transition:
  (but by all means do "svn ci" immediately before so you can easily revert):
    mod-ui-change-setSize-header *.h
    mod-ui-change-setSize-src *.cc
  This should do the trick, but make sure to double-check what it did.
  * All widgets:
  Most 'long' function parameters and return values are now 'int',
  including (but not restricted to):
  * widget sizes
  * widget positions
  * layout weights
  gcc should complain about missing places. Also remember to check for '%%ld' in
  y2debug() etc. calls and replace most of them with '%%d'.
  * Factories:
  * Derived UIs now are required to implement:
  * YWidgetFactory * createWidgetFactory()
  * YOptionalWidgetFactory * createOptionalWidgetFactory()
  * Moved widget creation methods to factories
  * New header file YTypes.h for simple types to reduce header file interdependencies:
  Now it's often no longer necessary to #include YAlignment.h or YWidget.h
  * YUI:
  * YUI::currentDialog() is now moved to static YDialog::currentDialog()
  * New: YApplication
  The idea of this class is to bundle all the "misc UI functionality" methods.
  See YApplication.h for details.
  * YDialog:
  * YUI::currentDialog() is now moved to YDialog::currentDialog()
  * YDialog::currentDialog() now throws exceptions by default (unless bool param == true),
    i.e. there is no more need to check for a 0 pointer after currentDialog()
    (but exceptions need to be caught somewhere)
  * YSplit:
  * renamed to YLayoutBox
  * YRadioButton:
  * Made all memeber variables private.
    Access via access functions only from now on.
  * value is now bool		, no longer YCPBoolean
  * label is now std::string	, no longer YCPString
  * YCPString getLabel()			-> std::string label()
  * void setLabel( YCPString )		-> setLabel( std::string )
  * virtual YCPBoolean getValue()		-> virtual bool value()
  * virtual void setValue( YCPBoolean )	-> virtual void setValue( bool )
  * new method: useBoldFont()  (instead of YWidgetOpt::boldFont() )
  * new method: boldFont()
  * YTextEntry:
  * Made all memeber variables private.
    Access via access functions only from now on.
  * label is now std::string	, no longer YCPString
  * passwordMode is now passed directly in the constructor, not only via YWidgetOpt
  * passwordMode is now a member, no longer avaliable only from YWidgetOpt
  * Renamed getText()	-> value(),
  * Renamed setText()	-> setValue()
  * virtual YCPString getText()		-> virtual std::string value()
  * virtual void setText( YCPString )		-> virtual void setValue( std::string )
  * getLabel() -> label()
  * virtual setValidChars( YCPStrng )		-> virtual setValidChars( std::string )
  * virtual setInputMaxLength( YCPInteger )	-> virtual setInputMaxLength( int )
  * overloaded virtual setInputMaxLength( int ) is now required to call
    YTextEntry::setInputMaxLength() at its end
  * YPushButton:
  * Made all memeber variables private.
    Access via access functions only from now on.
  * label is now std::string	, no longer YCPString
  * YReplacePoint:
  * now derived from YSingleChildContainerWidget
  * removed YWidget::isReplacePoint() / YReplacePoint::isReplacePoint()
  * no more YContainerWidget::childAdded(),
    reimplement YReplacePoint::showChild() instead.
  * YRadioButtonGroup:
  * no more std::vector<YRadioButton *> buttons,
    use iterators with buttonsBegin() and buttonsEnd() instead
  * YWidgetFactory:
  * createHeading()	is no longer virtual - remove from derived factory
  * createOutputField() is no longer virtual - remove from derived factory
